@@ -35,9 +35,9 @@ USERS = [
 
 class AthenaClient:
 
-    def connect(self, user_name, key, s3_staging_dir=None):
+    def connect(self, user_name, key):
         if (user_name.casefold(), key) in [(user['name'].casefold(), user['key']) for user in USERS]:
-            self._make_connection(s3_staging_dir)
+            self._make_connection()
             return f"Hello {user_name}, Your connection is successful..."
         else:
             return f"User - {user_name} is unauthorised."
